@@ -33,6 +33,7 @@ from distutils.version import LooseVersion
 
 from easybuild.tools.build_log import EasyBuildError
 from easybuild.tools.toolchain.fft import Fft
+from easybuild.tools.modules import get_software_root
 
 
 class Fftw(Fft):
@@ -56,6 +57,11 @@ class Fftw(Fft):
         fftw_libs = ["fftw%s" % suffix]
         if self.options.get('usempi', False):
             fftw_libs.insert(0, "fftw%s_mpi" % suffix)
+            fftwmpiroot = get_software_root('FFTW.MPI')
+            if fftwmpiroot:
+                # get libfft%_mpi via the FFTW.MPI module
+                self.FFT_MODULE_NAME = ['FFTW.MPI']
+
         fftw_libs_mt = ["fftw%s" % suffix]
         if self.options.get('openmp', False):
             fftw_libs_mt.insert(0, "fftw%s_omp" % suffix)
